import pytest

from program.tests.factories import MusicFocusFactory

pytestmark = pytest.mark.django_db


def url(music_focus=None):
    return f"/api/v1/music-focus/{music_focus.id}/" if music_focus else "/api/v1/music-focus/"


def test_create(admin_api_client):
    data = {
        "name": "NAME",
        "slug": "music-focus",
    }

    response = admin_api_client.post(url(), data)

    assert response.status_code == 201

    assert response.data["name"] == data["name"]
    assert response.data["slug"] == data["slug"]


def test_retrieve_music_focus(common_api_client1, music_focus):
    response = common_api_client1.get(url(music_focus=music_focus))

    assert response.status_code == 200

    assert response.data["name"] == music_focus.name
    assert response.data["slug"] == music_focus.slug


def test_delete(admin_api_client, music_focus):
    response = admin_api_client.delete(url(music_focus=music_focus))

    assert response.status_code == 204


def test_list(common_api_client1):
    MUSIC_FOCUS = 3
    MusicFocusFactory.create_batch(size=MUSIC_FOCUS)

    response = common_api_client1.get(url())

    assert response.status_code == 200
    assert len(response.data) == MUSIC_FOCUS


def test_update_is_active(admin_api_client, music_focus):
    update = {"is_active": False}

    response = admin_api_client.patch(url(music_focus=music_focus), update)

    assert response.status_code == 200
    assert response.data["is_active"] is update["is_active"]


def test_update_name(admin_api_client, music_focus):
    update = {"name": "NAME"}

    response = admin_api_client.patch(url(music_focus=music_focus), update)

    assert response.status_code == 200
    assert response.data["name"] == update["name"]


def test_update_slug(admin_api_client, music_focus):
    update = {"slug": "music-focus"}

    response = admin_api_client.patch(url(music_focus=music_focus), update)

    assert response.status_code == 200
    assert response.data["slug"] == update["slug"]
